@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -55,7 +55,7 @@ command_new (gpointer   callback_data,
 }
 
 
-#ifndef G_OS_WIN32
+#if ! defined G_OS_WIN32 && ! defined USE_GTK24
 static void
 command_open_ok (GtkWidget *widget,
                  GtkWidget *dialog)
@@ -67,7 +67,7 @@ command_open_ok (GtkWidget *widget,
                                                 (GTK_FILE_SELECTION (dialog)));
   gtk_widget_destroy (dialog);
 }
-#endif /* not G_OS_WIN32 */
+#endif /* ! defined G_OS_WIN32 && ! defined USE_GTK24 */
 
 
 void
@@ -146,7 +146,19 @@ command_open (gpointer   callback_data,
 #else /* not G_OS_WIN32 */
   GtkWidget *dialog;
 
-  dialog=gtk_file_selection_new(_("Open"));
+# ifdef USE_GTK24
+  dialog = gtk_file_chooser_dialog_new (_("Open"),
+                        GTK_WINDOW (window), GTK_FILE_CHOOSER_ACTION_OPEN,
+                        GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                        NULL);
+  if (open_path)
+    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), open_path);
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+    file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+  gtk_widget_destroy (dialog);
+# else /* not USE_GTK24 */
+  dialog = gtk_file_selection_new (_("Open"));
   g_signal_connect (G_OBJECT (dialog), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
   g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (dialog)->ok_button),
@@ -161,14 +173,15 @@ command_open (gpointer   callback_data,
   gtk_widget_show (dialog);
   gtk_grab_add (dialog);
   gtk_main ();
+# endif /* not USE_GTK24 */
 #endif /* not G_OS_WIN32 */
   if (file)
     {
-      g_free(open_path);
+      g_free (open_path);
       open_path = fileio_get_full_path (file);
-      *(gchar *)g_basename(open_path)='\0';
-      file_open_edit(file);
-      g_free(file);
+      *(gchar *)g_basename (open_path) = '\0';
+      file_open_edit (file);
+      g_free (file);
     }
 }
 
@@ -285,6 +298,18 @@ command_saveas (gpointer   callback_data,
 #else /* not G_OS_WIN32 */
   GtkWidget *dialog;
 
+# ifdef USE_GTK24
+  dialog = gtk_file_chooser_dialog_new (_("Save As"),
+                        GTK_WINDOW (window), GTK_FILE_CHOOSER_ACTION_SAVE,
+                        GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
+                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                        NULL);
+  if (save_path)
+    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), save_path);
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
+    file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+  gtk_widget_destroy (dialog);
+# else /* not USE_GTK24 */
   dialog = gtk_file_selection_new (_("Save As"));
   g_signal_connect (G_OBJECT (dialog), "destroy",
                                             G_CALLBACK (gtk_main_quit), NULL);
@@ -300,6 +325,7 @@ command_saveas (gpointer   callback_data,
   gtk_widget_show (dialog);
   gtk_grab_add (dialog);
   gtk_main ();
+# endif /* not USE_GTK24 */
 #endif /* not G_OS_WIN32 */
   if (file)
     {
