@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -462,7 +462,8 @@ file_open_text (TmaidWindow *tmaid)
                     else
                       break;
                 }
-              if (i < j && j < p->length && p->text[j++] == ';')
+              if (i < j && j < p->length && p->text[j++]
+                                                    == G_SEARCHPATH_SEPARATOR)
                 {
                   i -= 2;
                   leng = g_unichar_to_utf8 (c, buf);
@@ -569,7 +570,8 @@ file_open_edit (const gchar *file)
       for (i = 0; i < ftnum; i++)
         {
           ext = g_strdup (ftype[i].ext);
-          for (p = g_strtok (ext, ";"); p; p = g_strtok (NULL, ";"))
+          for (p = g_strtok (ext, G_SEARCHPATH_SEPARATOR_S); p;
+                                p = g_strtok (NULL, G_SEARCHPATH_SEPARATOR_S))
             if (g_pattern_match_simple (p, text))
               goto loop;
           g_free (ext);
