@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 /******************************************************************************
 *                                                                             *
 * ja:ファイルタイプ選択ダイアログ関数群                                       *
@@ -34,4 +39,9 @@
 gboolean ftype_dialog(gint *pos);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
