@@ -90,10 +90,20 @@ property_change (TmaidWindow *tmaid,
   property_copy (&tmaid->ft, ft);
   tmaid->select.x = -1;
   /* ja:フォント */
-  gtk_widget_modify_font (window, tmaid->ft.font_name
-                    ? pango_font_description_from_string (tmaid->ft.font_name)
-                    : pango_font_description_copy (system_font));
-  tmaid->layout = gtk_widget_create_pango_layout (window, NULL);
+  g_object_unref (tmaid->layout);
+  if (tmaid->ft.font_name)
+    {
+      PangoFontDescription *desc;
+
+      desc = pango_font_description_from_string (tmaid->ft.font_name);
+      gtk_widget_modify_font (tmaid->drawing, desc);
+      pango_font_description_free (desc);
+    }
+  else
+    {
+      gtk_widget_modify_font (tmaid->drawing, system_font);
+    }
+  tmaid->layout = gtk_widget_create_pango_layout (tmaid->drawing, NULL);
   charset_size (tmaid->layout, &tmaid->font_width, &tmaid->font_height,
                                                             tmaid->font_buf);
   if (modify)
