@@ -109,6 +109,21 @@ signal_realize (GtkWidget   *widget,
   gdk_window_set_cursor (widget->window, cursor);
   gdk_cursor_unref (cursor);
   gtk_im_context_set_client_window (tmaid->im_context, widget->window);
+  /* ja:フォント */
+  g_object_unref (tmaid->layout);
+  if (tmaid->ft.font_name)
+    {
+      PangoFontDescription *desc;
+
+      desc = pango_font_description_from_string (tmaid->ft.font_name);
+      gtk_widget_modify_font (widget, desc);
+      pango_font_description_free (desc);
+    }
+  else
+    {
+      gtk_widget_modify_font (widget, system_font);
+    }
+  tmaid->layout = gtk_widget_create_pango_layout (widget, NULL);
 }
 
 
