@@ -70,8 +70,7 @@ signal_style_set (GtkWidget *widget,
             {
               /* ja:フォント変更 */
               g_object_unref (tmaid->layout);
-              gtk_widget_modify_font (tmaid->drawing,
-                                    pango_font_description_copy (system_font));
+              gtk_widget_modify_font (tmaid->drawing, system_font);
               tmaid->layout = gtk_widget_create_pango_layout
                                                         (tmaid->drawing, NULL);
               charset_size (tmaid->layout,
