@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,16 +22,16 @@
 
 /******************************************************************************
 *                                                                             *
-* ġСؿ                                                            *
+* ja:ツールバー関数群                                                         *
 *                                                                             *
 ******************************************************************************/
 /* XPM */
-static gchar *tb_new_xpm[]={
+static gchar *tb_new_xpm[] = {
 "16 16 4 1",
-" 	c None",
-".	c #000000",
-"+	c #FF0000",
-"@	c #FFFFFF",
+"   c None",
+".  c #000000",
+"+  c #FF0000",
+"@  c #FFFFFF",
 "          +     ",
 " ......+..+..+  ",
 " .@@@@@@+@+@+   ",
@@ -51,13 +51,13 @@ static gchar *tb_new_xpm[]={
 
 
 /* XPM */
-static gchar *tb_open_xpm[]={
+static gchar *tb_open_xpm[] = {
 "16 16 5 1",
-" 	c None",
-".	c #000000",
-"=	c #808080",
-">	c #FFFF00",
-"!	c #FFFFFF",
+"   c None",
+".  c #000000",
+"=  c #808080",
+">  c #FFFF00",
+"!  c #FFFFFF",
 "  ......        ",
 " .!>!>!>.       ",
 ".!>!>!>!>.......",
@@ -77,7 +77,7 @@ static gchar *tb_open_xpm[]={
 
 
 /* XPM */
-static gchar *tb_save_xpm[]={
+static gchar *tb_save_xpm[] = {
 "16 16 5 1",
 "  c None",
 ". c #000000",
@@ -102,7 +102,7 @@ static gchar *tb_save_xpm[]={
 "                "};
 
 
-static gchar *tb_prop_xpm[]={
+static gchar *tb_prop_xpm[] = {
 "16 16 4 1",
 "  c None",
 ". c #000000",
@@ -126,15 +126,15 @@ static gchar *tb_prop_xpm[]={
 "                "};
 
 
-static gchar *tb_print_xpm[]={
+static gchar *tb_print_xpm[] = {
 "16 16 7 1",
-" 	c None",
-".	c #000000",
-"#	c #808000",
-"*	c #C0C0C0",
-"=	c #808080",
-";	c #00FF00",
-"!	c #FFFFFF",
+"   c None",
+".  c #000000",
+"#  c #808000",
+"*  c #C0C0C0",
+"=  c #808080",
+";  c #00FF00",
+"!  c #FFFFFF",
 "     .......... ",
 "     .!!!!!!!!. ",
 "     .!*****!!. ",
@@ -154,13 +154,13 @@ static gchar *tb_print_xpm[]={
 
 
 /* XPM */
-static gchar *tb_cut_xpm[]={
+static gchar *tb_cut_xpm[] = {
 "16 16 5 1",
-" 	c None",
-".	c #000000",
-"-	c #FF0000",
-",	c #0000FF",
-"!	c #FFFFFF",
+"   c None",
+".  c #000000",
+"-  c #FF0000",
+",  c #0000FF",
+"!  c #FFFFFF",
 "                ",
 "....         ,, ",
 "!!!.        ,  ,",
@@ -180,12 +180,12 @@ static gchar *tb_cut_xpm[]={
 
 
 /* XPM */
-static gchar *tb_copy_xpm[]={
+static gchar *tb_copy_xpm[] = {
 "16 16 4 1",
-" 	c None",
-".	c #000000",
-"-	c #FF0000",
-"!	c #FFFFFF",
+"   c None",
+".  c #000000",
+"-  c #FF0000",
+"!  c #FFFFFF",
 "    .........   ",
 "    .!!!!!!!.   ",
 "    .!!!!!!!.   ",
@@ -205,13 +205,13 @@ static gchar *tb_copy_xpm[]={
 
 
 /* XPM */
-static gchar *tb_paste_xpm[]={
+static gchar *tb_paste_xpm[] = {
 "16 16 5 1",
-" 	c None",
-".	c #000000",
-"*	c #C0C0C0",
-"=	c #808080",
-"!	c #FFFFFF",
+"   c None",
+".  c #000000",
+"*  c #C0C0C0",
+"=  c #808080",
+"!  c #FFFFFF",
 "                ",
 "     .........  ",
 "     .!!!!!!!.  ",
@@ -231,10 +231,10 @@ static gchar *tb_paste_xpm[]={
 
 
 /* XPM */
-static gchar *tb_delete_xpm[]={
+static gchar *tb_delete_xpm[] = {
 "16 16 2 1",
-" 	c None",
-",	c #0000FF",
+"   c None",
+",  c #0000FF",
 "                ",
 "                ",
 "                ",
@@ -254,10 +254,10 @@ static gchar *tb_delete_xpm[]={
 
 
 /* XPM */
-static gchar *tb_undo_xpm[]={
+static gchar *tb_undo_xpm[] = {
 "16 16 2 1",
-" 	c None",
-"-	c #FF0000",
+"   c None",
+"-  c #FF0000",
 "                ",
 "      ---       ",
 "    -------     ",
@@ -277,10 +277,10 @@ static gchar *tb_undo_xpm[]={
 
 
 /* XPM */
-static gchar *tb_redo_xpm[]={
+static gchar *tb_redo_xpm[] = {
 "16 16 2 1",
-" 	c None",
-",	c #0000FF",
+"   c None",
+",  c #0000FF",
 "            ,,  ",
 "   ,,       ,,  ",
 "  ,,,,      ,,  ",
@@ -300,13 +300,13 @@ static gchar *tb_redo_xpm[]={
 
 
 /* XPM */
-static gchar *tb_find_xpm[]={
+static gchar *tb_find_xpm[] = {
 "16 16 5 1",
-" 	c None",
-".	c #000000",
-"$	c #000080",
-",	c #0000FF",
-"!	c #FFFFFF",
+"   c None",
+".  c #000000",
+"$  c #000080",
+",  c #0000FF",
+"!  c #FFFFFF",
 "         ....   ",
 "        .    .  ",
 "       .    !!. ",
@@ -326,13 +326,13 @@ static gchar *tb_find_xpm[]={
 
 
 /* XPM */
-static gchar *tb_replace_xpm[]={
+static gchar *tb_replace_xpm[] = {
 "16 16 5 1",
-" 	c None",
-".	c #000000",
-"-	c #FF0000",
-",	c #0000FF",
-"!	c #FFFFFF",
+"   c None",
+".  c #000000",
+"-  c #FF0000",
+",  c #0000FF",
+"!  c #FFFFFF",
 "                ",
 "   -----        ",
 "       --       ",
@@ -351,51 +351,23 @@ static gchar *tb_replace_xpm[]={
 "       ,        "};
 
 
-#ifdef G_OS_WIN32
-/* XPM */
-static gchar *tb_close_xpm[]={
-"16 16 2 1",
-" 	c None",
-".	c #000000",
-"                ",
-"                ",
-"   ..      ..   ",
-"    ..    ..    ",
-"     ..  ..     ",
-"      ....      ",
-"       ..       ",
-"       ..       ",
-"      ....      ",
-"     ..  ..     ",
-"    ..    ..    ",
-"   ..      ..   ",
-"                ",
-"                ",
-"                "};
-#endif /* G_OS_WIN32 */
-
-
-ToolBar toolbar_items[]={
-/*  0 */ {N_("New"),       tb_new_xpm,    command_new,     NULL,NULL},
-/*  1 */ {N_("Open"),      tb_open_xpm,   command_open,    NULL,NULL},
-/*  2 */ {N_("Save"),      tb_save_xpm,   command_save,    NULL,NULL},
-/*  3 */ {NULL,            NULL,          NULL,            NULL,NULL},
-/*  4 */ {N_("Properties"),tb_prop_xpm,   command_property,NULL,NULL},
-/*  5 */ {NULL,            NULL,          NULL,            NULL,NULL},
-/*  6 */ {N_("Print"),     tb_print_xpm,  command_print,   NULL,NULL},
-/*  7 */ {NULL,            NULL,          NULL,            NULL,NULL},
-/*  8 */ {N_("Cut"),       tb_cut_xpm,    command_cut,     NULL,NULL},
-/*  9 */ {N_("Copy"),      tb_copy_xpm,   command_copy,    NULL,NULL},
-/* 10 */ {N_("Paste"),     tb_paste_xpm,  command_paste,   NULL,NULL},
-/* 11 */ {N_("Delete"),    tb_delete_xpm, command_delete,  NULL,NULL},
-/* 12 */ {NULL,            NULL,          NULL,            NULL,NULL},
-/* 13 */ {N_("Undo"),      tb_undo_xpm,   command_undo,    NULL,NULL},
-/* 14 */ {N_("Redo"),      tb_redo_xpm,   command_redo,    NULL,NULL},
-/* 15 */ {NULL,            NULL,          NULL,            NULL,NULL},
-/* 16 */ {N_("Find"),      tb_find_xpm,   command_find,    NULL,NULL},
-/* 17 */ {N_("Replace"),   tb_replace_xpm,command_replace, NULL,NULL},
-#ifdef G_OS_WIN32
-/* 18 */ {NULL,            NULL,          NULL,            NULL,NULL},
-/* 19 */ {N_("Close"),     tb_close_xpm,  command_close,   NULL,NULL},
-#endif /* G_OS_WIN32 */
-/*    */ {(gpointer)-1,    NULL,          NULL,            NULL,NULL}};
+ToolBar toolbar_items[] = {
+/*  0 */ {N_("New"),        tb_new_xpm,     command_new,      NULL, NULL},
+/*  1 */ {N_("Open"),       tb_open_xpm,    command_open,     NULL, NULL},
+/*  2 */ {N_("Save"),       tb_save_xpm,    command_save,     NULL, NULL},
+/*  3 */ {NULL,             NULL,           NULL,             NULL, NULL},
+/*  4 */ {N_("Properties"), tb_prop_xpm,    command_property, NULL, NULL},
+/*  5 */ {NULL,             NULL,           NULL,             NULL, NULL},
+/*  6 */ {N_("Print"),      tb_print_xpm,   command_print,    NULL, NULL},
+/*  7 */ {NULL,             NULL,           NULL,             NULL, NULL},
+/*  8 */ {N_("Cut"),        tb_cut_xpm,     command_cut,      NULL, NULL},
+/*  9 */ {N_("Copy"),       tb_copy_xpm,    command_copy,     NULL, NULL},
+/* 10 */ {N_("Paste"),      tb_paste_xpm,   command_paste,    NULL, NULL},
+/* 11 */ {N_("Delete"),     tb_delete_xpm,  command_delete,   NULL, NULL},
+/* 12 */ {NULL,             NULL,           NULL,             NULL, NULL},
+/* 13 */ {N_("Undo"),       tb_undo_xpm,    command_undo,     NULL, NULL},
+/* 14 */ {N_("Redo"),       tb_redo_xpm,    command_redo,     NULL, NULL},
+/* 15 */ {NULL,             NULL,           NULL,             NULL, NULL},
+/* 16 */ {N_("Find"),       tb_find_xpm,    command_find,     NULL, NULL},
+/* 17 */ {N_("Replace"),    tb_replace_xpm, command_replace,  NULL, NULL},
+/*    */ {(gpointer)-1,     NULL,           NULL,             NULL, NULL}};
