@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,11 +19,15 @@
 #include <windows.h>
 
 
-int main(int,char **);
+int
+main (int, char **);
 
 
-int WINAPI WinMain(HINSTANCE hInstance,HINSTANCE hPrevInstance,
-												LPSTR lpszCmdLine,int nCmdShow)
+int WINAPI
+WinMain (HINSTANCE hInstance,
+         HINSTANCE hPrevInstance,
+         LPSTR     lpszCmdLine,
+         int       nCmdShow)
 {
-	return main(__argc,__argv);
+  return main (__argc, __argv);
 }
